@@ -60,7 +60,6 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-swift \
     puppet-systemd \
     puppetlabs-sysctl \
-    puppet-tempest \
     puppet-timezone \
     puppetlabs-vcsrepo \
     puppet-vlan \
@@ -84,7 +83,8 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-kmod \
     puppet-etcd \
     puppet-zaqar \
-    puppet-veritas_hyperscale; do
+    puppet-veritas_hyperscale \
+    puppet-ptp; do
     export DIB_INSTALLTYPE_${module_name//\-/_}='source'
   done
 fi
